@@ -1,50 +1,28 @@
-# -*- coding: utf-8 -*-
-################################################################################
-#  Copyright (C) 2013-2014  Travis Shirk <travis@pobox.com>
-#
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, see <http://www.gnu.org/licenses/>.
-#
-################################################################################
-from __future__ import print_function
 import os
 from collections import defaultdict
 
 from eyed3.id3 import ID3_V2_4
 from eyed3.id3.tag import TagTemplate
 from eyed3.plugins import LoaderPlugin
-from eyed3.compat import UnicodeType
 from eyed3.utils import art
 from eyed3.utils.prompt import prompt
 from eyed3.utils.console import printMsg, Style, Fore
-from eyed3 import core, compat
+from eyed3 import core
 
 from eyed3.core import (ALBUM_TYPE_IDS, TXXX_ALBUM_TYPE, EP_MAX_SIZE_HINT,
                         LP_TYPE, EP_TYPE, COMP_TYPE, VARIOUS_TYPE, DEMO_TYPE,
                         LIVE_TYPE, SINGLE_TYPE, VARIOUS_ARTISTS)
 
-NORMAL_FNAME_FORMAT = u"${artist} - ${track:num} - ${title}"
-VARIOUS_FNAME_FORMAT = u"${track:num} - ${artist} - ${title}"
-SINGLE_FNAME_FORMAT = u"${artist} - ${title}"
+NORMAL_FNAME_FORMAT = "${artist} - ${track:num} - ${title}"
+VARIOUS_FNAME_FORMAT = "${track:num} - ${artist} - ${title}"
+SINGLE_FNAME_FORMAT = "${artist} - ${title}"
 
-NORMAL_DNAME_FORMAT = u"${best_date:prefer_release} - ${album}"
-LIVE_DNAME_FORMAT = u"${best_date:prefer_recording} - ${album}"
+NORMAL_DNAME_FORMAT = "${best_date:prefer_release} - ${album}"
+LIVE_DNAME_FORMAT = "${best_date:prefer_recording} - ${album}"
 
 
 def _printChecking(msg, end='\n'):
-    print(Style.BRIGHT + Fore.GREEN + u"Checking" + Style.RESET_ALL +
-          " %s" % msg,
-          end=end)
+    print(Style.BRIGHT + Fore.GREEN + "Checking" + Style.RESET_ALL + " %s" % msg, end=end)
 
 
 def _fixCase(s):
@@ -52,7 +30,7 @@ def _fixCase(s):
         fixed_values = []
         for word in s.split():
             fixed_values.append(word.capitalize())
-        return u" ".join(fixed_values)
+        return " ".join(fixed_values)
     else:
         return s
 
@@ -66,9 +44,8 @@ def dirDate(d):
 
 class FixupPlugin(LoaderPlugin):
     NAMES = ["fixup"]
-    SUMMARY = \
-            u"Performs various checks and fixes to directories of audio files."
-    DESCRIPTION = u"""
+    SUMMARY = "Performs various checks and fixes to directories of audio files."
+    DESCRIPTION = """
 Operates on directories at a time, fixing each as a unit (album,
 compilation, live set, etc.). All of these should have common dates,
 for example but other characteristics may vary. The ``--type`` should be used
@@ -130,8 +107,7 @@ Album types:
         self._handled_one = False
 
         g.add_argument("--type", choices=ALBUM_TYPE_IDS, dest="dir_type",
-                       default=None, type=UnicodeType,
-                       help=ARGS_HELP["--type"])
+                       default=None, help=ARGS_HELP["--type"])
         g.add_argument("--fix-case", action="store_true", dest="fix_case",
                        help=ARGS_HELP["--fix-case"])
         g.add_argument("-n", "--dry-run", action="store_true", dest="dry_run",
@@ -144,10 +120,12 @@ Album types:
                        help=ARGS_HELP["--file-rename-pattern"])
         g.add_argument("--dir-rename-pattern", dest="dir_rename_pattern",
                        help=ARGS_HELP["--dir-rename-pattern"])
+        g.add_argument("--no-dir-rename", action="store_true",
+                       help=ARGS_HELP["--no-dir-rename"])
         self._curr_dir_type = None
         self._dir_files_to_remove = set()
 
-    def _getOne(self, key, values, default=None, Type=UnicodeType,
+    def _getOne(self, key, values, default=None, Type=str,
                 required=True):
         values = set(values)
         if None in values:
@@ -155,15 +133,14 @@ Album types:
 
         if len(values) != 1:
             printMsg(
-                u"Detected %s %s names%s" %
+                "Detected %s %s names%s" %
                 ("0" if len(values) == 0 else "multiple",
                  key,
                  "." if not values
-                     else (":\n\t%s" % "\n\t".join([compat.unicode(v)
-                                                      for v in values])),
+                     else (":\n\t%s" % "\n\t".join([str(v) for v in values])),
                 ))
 
-            value = prompt(u"Enter %s" % key.title(), default=default,
+            value = prompt("Enter %s" % key.title(), default=default,
                            type_=Type, required=required)
         else:
             value = values.pop()
@@ -195,7 +172,7 @@ Album types:
             # The recording date is most meaningful for live music.
             recording_date = reduceDate("recording date",
                                         rec_dates | orel_dates | rel_dates)
-            rec_dates = set([recording_date])
+            rec_dates = {recording_date}
 
             # Want when these set if they may recording time.
             orel_dates.difference_update(rec_dates)
@@ -204,7 +181,7 @@ Album types:
             if orel_dates:
                 original_release_date = reduceDate("original release date",
                                                    orel_dates | rel_dates)
-            orel_dates = set([original_release_date])
+            orel_dates = {original_release_date}
 
             if rel_dates | orel_dates:
                 release_date = reduceDate("release date",
@@ -215,25 +192,21 @@ Album types:
             # The release date is most meaningful for comps, other track dates
             # may differ.
             if len(rel_dates) != 1:
-                release_date = reduceDate("release date",
-                                          rel_dates | orel_dates)
-                rel_dates = set([release_date])
+                release_date = reduceDate("release date", rel_dates | orel_dates)
             else:
                 release_date = list(rel_dates)[0]
         else:
             if len(orel_dates) != 1:
                 # The original release date is most meaningful for studio music.
                 original_release_date = reduceDate("original release date",
-                                                   orel_dates | rel_dates |
-                                                   rec_dates)
-                orel_dates = set([original_release_date])
+                                                   orel_dates | rel_dates | rec_dates)
+                orel_dates = {original_release_date}
             else:
                 original_release_date = list(orel_dates)[0]
 
             if len(rel_dates) != 1:
-                release_date = reduceDate("release date",
-                                          rel_dates | orel_dates)
-                rel_dates = set([release_date])
+                release_date = reduceDate("release date", rel_dates | orel_dates)
+                rel_dates = {release_date}
             else:
                 release_date = list(rel_dates)[0]
 
@@ -275,7 +248,7 @@ Album types:
         # Fix up artist and album artist discrepancies
         if len(artists) == 1 and album_artist:
             artist = artists[0]
-            if (album_artist != artist):
+            if album_artist != artist:
                 print("When there is only one artist it should match the "
                       "album artist. Choices are: ")
                 for s in [artist, album_artist]:
@@ -294,7 +267,7 @@ Album types:
         albums = set([t.album for t in tags if t.album])
         album_name = (albums.pop() if len(albums) == 1
                                    else self._getOne("album", albums))
-        assert(album_name)
+        assert album_name
         return album_name if not self.args.fix_case else _fixCase(album_name)
 
     def _checkCoverArt(self, directory, audio_files):
@@ -306,7 +279,7 @@ Album types:
             art_type = art.matchArtFile(dimg)
             if art_type == art.FRONT_COVER:
                 dimg_name = os.path.basename(dimg)
-                print("\t%s" % dimg_name)
+                print(f"\t{dimg_name}")
                 valid_cover = True
 
         if not valid_cover:
@@ -319,14 +292,14 @@ Album types:
                 for img in tag.images:
                     if img.picture_type == img.FRONT_COVER:
                         file_name = img.makeFileName("cover")
-                        print("\tFound front cover in tag, writing '%s'" %
-                              file_name)
-                        with open(os.path.join(directory, file_name),
-                                  "wb") as img_file:
+                        print("\tFound front cover in tag, writing '%s'" % file_name)
+                        with open(os.path.join(directory, file_name), "wb") as img_file:
                             img_file.write(img.image_data)
                             img_file.close()
                             valid_cover = True
 
+        # TODO: force rename of cover file to single/consistent name (e.g. cover)
+
         return valid_cover
 
     def start(self, args, config):
@@ -345,7 +318,7 @@ Album types:
             return
 
         directory = os.path.abspath(directory)
-        print("\n" + Style.BRIGHT + Fore.GREY +
+        print("\n" + Style.BRIGHT + Fore.YELLOW +
               "Scanning directory%s %s" % (Style.RESET_ALL, directory))
 
         def _path(af):
@@ -396,10 +369,10 @@ Album types:
 
         if self._curr_dir_type != SINGLE_TYPE:
             album_artist, artists = self._resolveArtistInfo(audio_files)
-            print(Fore.BLUE + u"Album artist: " + Style.RESET_ALL +
-                  (album_artist or u""))
+            print(Fore.BLUE + "Album artist: " + Style.RESET_ALL +
+                  (album_artist or ""))
             print(Fore.BLUE + "Artist" + ("s" if len(artists) > 1 else "") +
-                  ": " + Style.RESET_ALL + u", ".join(artists))
+                  ": " + Style.RESET_ALL + ", ".join(artists))
 
             album = self._getAlbum(audio_files)
             print(Fore.BLUE + "Album: " + Style.RESET_ALL + album)
@@ -408,8 +381,7 @@ Album types:
             for what, d in [("Release", rel_date),
                             ("Original", orel_date),
                             ("Recording", rec_date)]:
-                print(Fore.BLUE + ("%s date: " % what) + Style.RESET_ALL +
-                        str(d))
+                print(f"{Fore.BLUE} {what} date: {Style.RESET_ALL} {d}")
 
             num_audio_files = len(audio_files)
             track_nums = set([f.tag.track_num[0] for f in audio_files])
@@ -418,8 +390,8 @@ Album types:
 
         dir_type = self._curr_dir_type
         for f in sorted(audio_files, key=_path):
-            print(Style.BRIGHT + Fore.GREEN + u"Checking" + Fore.RESET +
-                  Fore.GREY + (" %s" % os.path.basename(f.path)) +
+            print(Style.BRIGHT + Fore.GREEN + "Checking" + Fore.RESET +
+                  Style.BRIGHT + (" %s" % os.path.basename(f.path)) +
                   Style.RESET_ALL)
 
             if not f.tag:
@@ -433,8 +405,8 @@ Album types:
                 tag.version = ID3_V2_4
                 edited_files.add(f)
 
-            if (dir_type != SINGLE_TYPE and album_artist != tag.album_artist):
-                print(u"\tSetting album artist: %s" % album_artist)
+            if dir_type != SINGLE_TYPE and album_artist != tag.album_artist:
+                print("\tSetting album artist: %s" % album_artist)
                 tag.album_artist = album_artist
                 edited_files.add(f)
 
@@ -444,12 +416,12 @@ Album types:
                 last["artist"] = tag.artist
             elif len(artists) == 1 and tag.artist != artists[0]:
                 assert(dir_type != SINGLE_TYPE)
-                print(u"\tSetting artist: %s" % artists[0])
+                print("\tSetting artist: %s" % artists[0])
                 tag.artist = artists[0]
                 edited_files.add(f)
 
             if tag.album != album and dir_type != SINGLE_TYPE:
-                print(u"\tSetting album: %s" % album)
+                print("\tSetting album: %s" % album)
                 tag.album = album
                 edited_files.add(f)
 
@@ -460,7 +432,7 @@ Album types:
             if self.args.fix_case:
                 tag.title = _fixCase(tag.title)
             if orig_title != tag.title:
-                print(u"\tSetting title: %s" % tag.title)
+                print("\tSetting title: %s" % tag.title)
                 edited_files.add(f)
 
             if dir_type != SINGLE_TYPE:
@@ -528,7 +500,7 @@ Album types:
                 tlen_ms = float(tlen)
                 if tlen_ms != real_tlen_ms:
                     print("\tSetting TLEN (%d)" % real_tlen_ms)
-                    tag.setTextFrame("TLEN", UnicodeType(real_tlen_ms))
+                    tag.setTextFrame("TLEN", str(real_tlen_ms))
                     edited_files.add(f)
 
             # Add custom album type if special and otherwise not able to be
@@ -565,12 +537,12 @@ Album types:
             orig_name, orig_ext = os.path.splitext(os.path.basename(f.path))
             new_name = TagTemplate(format_str).substitute(f.tag, zeropad=True)
             if orig_name != new_name:
-                printMsg(u"Rename file to %s%s" % (new_name, orig_ext))
+                printMsg("Rename file to %s%s" % (new_name, orig_ext))
                 file_renames.append((f, new_name, orig_ext))
 
         # Directory renaming
         dir_rename = None
-        if dir_type != SINGLE_TYPE:
+        if not self.args.no_dir_rename and dir_type != SINGLE_TYPE:
             if self.args.dir_rename_pattern:
                 dir_format = self.args.dir_rename_pattern
             else:
@@ -603,11 +575,11 @@ Album types:
 
             if confirmed:
                 for f in edited_files:
-                    print(u"Saving %s" % os.path.basename(f.path))
+                    print("Saving %s" % os.path.basename(f.path))
                     f.tag.save(version=ID3_V2_4, preserve_file_time=True)
 
                 for f, new_name, orig_ext in file_renames:
-                    printMsg(u"Renaming file to %s%s" % (new_name, orig_ext))
+                    printMsg("Renaming file to %s%s" % (new_name, orig_ext))
                     f.rename(new_name, preserve_file_time=True)
 
                 if file_removes:
@@ -655,4 +627,5 @@ ARGS_HELP = {
         "--dir-rename-pattern": "Rename directory based on data in the tag "
                                 "using substitution variables: " +
                                 _getTemplateKeys(),
+        "--no-dir-rename": "Do not rename the directory.",
 }
